==> em_tasks-0.1.35-py2.py3-none-any.whl: em_tasks/utils/ebay_uploadable_products_filter.py <==
# -*- coding: utf-8 -*-

from em_tasks import logger
from em_tasks.utils.product_service import ProductService
from em_tasks.store.store_util import StoreUtil
from em_tasks.store.models import *


class EbayUploadableProductsFilter():
  def __init__(self, marketplace, product_service, output_path):
    self.product_service = product_service
    self.marketplace = marketplace
    self.indice_name = 'ebay_{}_products'.format(marketplace.lower())
    self.output_path = os.path.abspath(os.path.expanduser(output_path))
    output_dir = os.path.dirname(self.output_path)
    if not os.path.isdir(output_dir):
      os.makedirs(output_dir)
    self.output_fh = open(self.output_path, 'w+', encoding='utf-8', errors='ignore')

  def filter(self):
    try:
      blacklisted_path = './ebay_blacklisted.txt'
      records = dict()
      if os.path.isfile(blacklisted_path):
        with open(blacklisted_path, encoding='utf-8', errors='ignore') as fh:
          for line in fh:
            records[line.strip()] = None
      else:
        for keyword in BlacklistKeyword.select().order_by(BlacklistKeyword.id.desc()).dicts():
          k = keyword['keywords']
          records[k]= []

          query = {
            'query': {
              'query': {
                'multi_match': {
                  'query': k,
                  'type': 'phrase',
                  'fields': ['title^10', 'description']
                }
              }
            }
          }
          for prod_id, _ in self.product_service.load_products(self.indice_name, query):
            records[prod_id] = None

        with open('./ebay_blacklisted.txt', 'w+', encoding='utf-8', errors='ignore') as fh:
          fh.write("\n".join(list(records.keys())))

      logger.debug('[BlacklistedProductsLoaded] ProductsCnt: %s', len(records))

      uploaded_prods = dict()
      for prod in StoreUtil.get_ebay_products(self.marketplace):
        uploaded_prods[prod['source_product_id']] = None

      logger.debug('[UploadedProductsLoaded] ProductsCnt: %s', len(uploaded_prods))

      for prod_id, prod in self.product_service.load_products(self.indice_name):
        exist = prod.get('existence', True)
        if not exist:
          continue

        has_only_default_variant = prod.get('has_only_default_variant', True)
        if not has_only_default_variant:
          continue

        if prod_id in records or prod_id in uploaded_prods:
          continue

        self.output_fh.write("{}\n".format(prod_id))
    finally:
      self.output_fh.close()

==> em_tasks-0.1.65-py2.py3-none-any.whl: em_tasks/utils/ebay_uploadable_products_filter.py <==
# -*- coding: utf-8 -*-

from em_tasks import logger
from em_tasks.utils.product_service import ProductService
from em_tasks.store.store_util import StoreUtil
from em_tasks.store.models import *


class EbayUploadableProductsFilter():
  def __init__(self, marketplace, product_service, output_path):
    self.product_service = product_service
    self.marketplace = marketplace
    self.indice_name = 'ebay_{}_products'.format(marketplace.lower())
    self.output_path = os.path.abspath(os.path.expanduser(output_path))
    output_dir = os.path.dirname(self.output_path)
    if not os.path.isdir(output_dir):
      os.makedirs(output_dir)
    self.output_fh = open(self.output_path, 'w+', encoding='utf-8', errors='ignore')

  def filter(self):
    try:
      blacklisted_path = './ebay_blacklisted.txt'
      records = dict()
      stats = dict()

      for keyword in BlacklistKeyword.select().order_by(BlacklistKeyword.id.desc()).dicts():
        k = keyword['keywords']
        stats[k] = 0

        query = {
          'query': {
            'query': {
              'multi_match': {
                'query': k,
                'type': 'phrase',
                'fields': ['title^10', 'description']
              }
            }
          }
        }
        for prod_id, _ in self.product_service.load_products(self.indice_name, query):
          records[prod_id] = None
          stats[k] += 1

      total_products_cnt = 0
      with open(blacklisted_path, 'w+', encoding='utf-8', errors='ignore') as fh:
        fh.write("\n".join(records.keys()))

      for k, products_cnt in stats.items():
        if not products_cnt:
          continue

        logger.debug('[BlacklistedProducts] Keyword: %s, ProductCnt: %s', k, products_cnt)
        total_products_cnt += products_cnt

      logger.debug('[BlacklistedProductsLoaded] ProductsCnt: %s', total_products_cnt)

      uploaded_prods = dict()
      for prod in StoreUtil.get_ebay_products(self.marketplace):
        uploaded_prods[prod['source_product_id']] = None

      logger.debug('[UploadedProductsLoaded] ProductsCnt: %s', len(uploaded_prods))

      for prod_id, prod in self.product_service.load_products(self.indice_name):
        exist = prod.get('existence', True)
        if not exist:
          continue

        has_only_default_variant = prod.get('has_only_default_variant', True)
        if not has_only_default_variant:
          continue

        if prod_id in records or prod_id in uploaded_prods:
          continue

        self.output_fh.write("{}\n".format(prod_id))
    finally:
      self.output_fh.close()
